﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="Program.cs" company="test">
//   none
// </copyright>
// <summary>
//   
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace TryDelimiter
{
    using System.Text;

    using MySql.Data.MySqlClient;

    /// <summary>
    /// Program to test MySqlScript class.
    /// </summary>
    internal class Program
    {
        #region Constants and Fields

        /// <summary>
        /// Holds connection string to test MySQL server.
        /// </summary>
        private const string ConnectionString = "server=localhost;user=root;port=3306;password=;CharSet=utf8;";

        /// <summary>
        /// Holds script which prepares empty TestDb.
        /// </summary>
        private const string SqlScriptToPrepareTestDb =
            "DROP DATABASE IF EXISTS TestDb; CREATE DATABASE TestDb; USE TestDb;";

        #endregion

        #region Methods

        /// <summary>
        /// Entry point of this program.
        /// </summary>
        private static void Main()
        {
            using (var connection = new MySqlConnection(ConnectionString))
            {
                connection.Open();

                PrepareTestDbDatabase(connection);
                TestScriptWithDelimiterStatements(connection);

                connection.Close();
            }
        }

        /// <summary>
        /// Prepares empty 'TestDb' database.
        /// </summary>
        /// <param name="connection">
        /// Connection to the MySql server.
        /// </param>
        private static void PrepareTestDbDatabase(MySqlConnection connection)
        {
            var script = new MySqlScript(connection, SqlScriptToPrepareTestDb);
            script.Execute();
        }

        /// <summary>
        /// Tests creation of two stored procedures using DELIMITER statement.
        /// </summary>
        /// <param name="connection">
        /// Connection to the MySql server.
        /// </param>
        private static void TestScriptWithDelimiterStatements(MySqlConnection connection)
        {
            var sql = new StringBuilder();

            sql.AppendLine("DELIMITER MySuperDelimiter");

            sql.AppendLine("CREATE PROCEDURE TestProcedure1()");
            sql.AppendLine("BEGIN");
            sql.AppendLine("  SELECT * FROM mysql.proc;");
            sql.AppendLine("END MySuperDelimiter");

            sql.AppendLine("CREATE PROCEDURE TestProcedure2()");
            sql.AppendLine("BEGIN");
            sql.AppendLine("  SELECT * FROM mysql.proc;");
            sql.AppendLine("END MySuperDelimiter");

            sql.AppendLine("DELIMITER ;");

            var script = new MySqlScript(connection, sql.ToString());
            script.Execute();
        }

        #endregion
    }
}